# ------------------------------------------------------------------------------
#  Created by Tyler Stegmaier
#  Copyright (c) 2021.
#
# ------------------------------------------------------------------------------

from .SwitchCase import *
from .test_tk import *
from .tests import *


def Run():
    import unittest
    unittest.main()
